"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.RegistrationActionsCreator = void 0;

var _dispatchActions = require("./dispatchActions");

/**
 * @packageDocumentation
 * @module RegistrationUIContext
 */

/**
 * Implementation of actions for altering the global [[RegistrationUIState]] via [[RegistrationUIActions]] calls.
 * Uses actions injected into the app to make network calls, and then updates the global state accordingly
 * using by dispatching [[RegistrationActions]] to the [[registrationReducer]].
 *
 * @param injectedActions Implementation of network activities.
 * @param dispatch For updating reducer upon completion of network activities.
 */
const RegistrationActionsCreator = (injectedActions, dispatch) => () => ({
  loadEULA: async language => {
    const transitId = Math.random();
    dispatch(_dispatchActions.RegistrationActions.loadEulaStarted(transitId, language));

    try {
      const eulaText = await injectedActions.loadEULA(language);
      dispatch(_dispatchActions.RegistrationActions.loadEulaSucceeded(transitId));
      return eulaText;
    } catch (error) {
      if (error instanceof Error) {
        dispatch(_dispatchActions.RegistrationActions.loadEulaFailed(transitId, error.message));
        throw error;
      } else throw error;
    }
  },
  requestRegistrationCode: async email => {
    const transitId = Math.random();
    dispatch(_dispatchActions.RegistrationActions.requestRegistrationCodeStarted(transitId));

    try {
      await injectedActions.requestRegistrationCode(email);
      dispatch(_dispatchActions.RegistrationActions.requestRegistrationCodeSucceeded(transitId));
    } catch (error) {
      if (error instanceof Error) {
        dispatch(_dispatchActions.RegistrationActions.requestRegistrationCodeFailed(transitId, error.message));
      } else throw error;
    }
  },
  validateUserRegistrationRequest: async (validationCode, validationEmail) => {
    const transitId = Math.random();
    dispatch(_dispatchActions.RegistrationActions.validateUserRegistrationStarted(transitId));

    try {
      const registrationComplete = await injectedActions.validateUserRegistrationRequest(validationCode, validationEmail);
      dispatch(_dispatchActions.RegistrationActions.validateUserRegistrationSucceeded(transitId));
      return registrationComplete;
    } catch (error) {
      if (error instanceof Error) {
        // Need this for debug. No real security risk
        if (validationCode === 'DEBUG_VALIDATION_CODE_DEADBEEF') {
          dispatch(_dispatchActions.RegistrationActions.validateUserRegistrationSucceeded(transitId));
          return false;
        }

        dispatch(_dispatchActions.RegistrationActions.validateUserRegistrationFailed(transitId, error.message));
        throw error;
      } else throw error;
    }
  },
  completeRegistration: async (userData, validationCode, validationEmail) => {
    const transitId = Math.random();
    dispatch(_dispatchActions.RegistrationActions.registerUserStarted(transitId));

    try {
      const userDetails = await injectedActions.completeRegistration(userData, validationCode, validationEmail);
      dispatch(_dispatchActions.RegistrationActions.registerUserSucceeded(transitId, userDetails.email, userDetails.organizationName));
      return userDetails;
    } catch (error) {
      if (error instanceof Error) {
        dispatch(_dispatchActions.RegistrationActions.registerUserFailed(transitId, error.message));
        throw error;
      } else throw error;
    }
  }
});

exports.RegistrationActionsCreator = RegistrationActionsCreator;
//# sourceMappingURL=actions.js.map